@@ -1,12 +1,35 @@
 /*
- * MUSCLE SmartCard Development ( http://www.linuxnet.com )
+ * MUSCLE SmartCard Development ( http://pcsclite.alioth.debian.org/pcsclite.html )
  *
  * Copyright (C) 1999-2002
- *  David Corcoran <corcoran@linuxnet.com>
+ *  David Corcoran <corcoran@musclecard.com>
  * Copyright (C) 2002-2011
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: debuglog.c 6759 2013-10-01 12:57:03Z rousseau $
+Redistribution and use in source and binary forms, with or without
+modification, are permitted provided that the following conditions
+are met:
+
+1. Redistributions of source code must retain the above copyright
+   notice, this list of conditions and the following disclaimer.
+2. Redistributions in binary form must reproduce the above copyright
+   notice, this list of conditions and the following disclaimer in the
+   documentation and/or other materials provided with the distribution.
+3. The name of the author may not be used to endorse or promote products
+   derived from this software without specific prior written permission.
+
+THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
+OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
+INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
+NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
+THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ * $Id$
  */
 
 /**
@@ -32,7 +55,6 @@
 #include "misc.h"
 #include "debuglog.h"
 #include "sys_generic.h"
-#include "strlcpycat.h"
 
 #ifdef NO_LOG
 
@@ -180,10 +202,10 @@ static void log_xxd_always(const int priority, const char *msg,
 	char DebugBuffer[len*3 + strlen(msg) +1];
 	int i;
 	char *c;
-	size_t l;
 
-	l = strlcpy(DebugBuffer, msg, sizeof(DebugBuffer));
-	c = DebugBuffer + l;
+	/* DebugBuffer is always big enough for msg */
+	strcpy(DebugBuffer, msg);
+	c = DebugBuffer + strlen(DebugBuffer);
 
 	for (i = 0; (i < len); ++i)
 	{
@@ -278,9 +300,6 @@ void DebugLogSetLevel(const int level)
 
 INTERNAL int DebugLogSetCategory(const int dbginfo)
 {
-#define DEBUG_INFO_LENGTH 80
-	char text[DEBUG_INFO_LENGTH];
-
 	/* use a negative number to UNset
 	 * typically use ~DEBUG_CATEGORY_APDU
 	 */
@@ -289,13 +308,8 @@ INTERNAL int DebugLogSetCategory(const int dbginfo)
 	else
 		LogCategory |= dbginfo;
 
-	/* set to empty string */
-	text[0] = '\0';
-
 	if (LogCategory & DEBUG_CATEGORY_APDU)
-		strlcat(text, " APDU", sizeof(text));
-
-	Log2(PCSC_LOG_INFO, "Debug options:%s", text);
+		Log1(PCSC_LOG_INFO, "Debug options: APDU");
 
 	return LogCategory;
 }
