@@ -29,7 +29,7 @@ THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: eventhandler.c 7004 2014-10-02 09:26:36Z rousseau $
+ * $Id$
  */
 
 /**
@@ -56,7 +56,6 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "sys_generic.h"
 #include "ifdwrapper.h"
 #include "prothandler.h"
-#include "strlcpycat.h"
 #include "utils.h"
 #include "winscard_svc.h"
 #include "simclist.h"
@@ -367,6 +366,8 @@ static void EHStatusHandlerThread(READER_CONTEXT * rContext)
 				dwCurrentState = SCARD_ABSENT;
 
 				rContext->readerState->eventCounter++;
+				if (rContext->readerState->eventCounter > 0xFFFF)
+					rContext->readerState->eventCounter = 0;
 
 				(void)EHSignalEventToClients();
 			}
@@ -415,6 +416,8 @@ static void EHStatusHandlerThread(READER_CONTEXT * rContext)
 				dwCurrentState = SCARD_PRESENT;
 
 				rContext->readerState->eventCounter++;
+				if (rContext->readerState->eventCounter > 0xFFFF)
+					rContext->readerState->eventCounter = 0;
 
 				Log2(PCSC_LOG_INFO, "Card inserted into %s", readerName);
 
