@@ -29,7 +29,7 @@ THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: hotplug_libudev.c 7033 2014-11-07 10:04:52Z rousseau $
+ * $Id$
  */
 
 /**
@@ -40,6 +40,7 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "config.h"
 #if defined(HAVE_LIBUDEV) && defined(USE_USB)
 
+#define _GNU_SOURCE		/* for asprintf(3) */
 #include <string.h>
 #include <stdio.h>
 #include <dirent.h>
@@ -54,7 +55,6 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "sys_generic.h"
 #include "hotplug.h"
 #include "utils.h"
-#include "strlcpycat.h"
 
 #ifndef TEMP_FAILURE_RETRY
 #define TEMP_FAILURE_RETRY(expression) \
@@ -378,8 +378,8 @@ static void HPRemoveDevice(struct udev_device *dev)
 static void HPAddDevice(struct udev_device *dev)
 {
 	int i;
-	char deviceName[MAX_DEVICENAME];
-	char fullname[MAX_READERNAME];
+	char *deviceName = NULL;
+	char *fullname = NULL;
 	struct _driverTracker *driver, *classdriver;
 	const char *sSerialNumber = NULL, *sInterfaceName = NULL;
 	const char *sInterfaceNumber;
@@ -440,10 +440,8 @@ static void HPAddDevice(struct udev_device *dev)
 	else
 		bInterfaceNumber = 0;
 
-	(void)snprintf(deviceName, sizeof(deviceName),
-		"usb:%04x/%04x:libudev:%d:%s", driver->manuID, driver->productID,
-		bInterfaceNumber, devpath);
-	deviceName[sizeof(deviceName) -1] = '\0';
+	asprintf(&deviceName, "usb:%04x/%04x:libudev:%d:%s",
+		driver->manuID, driver->productID, bInterfaceNumber, devpath);
 
 	/* find a free entry */
 	for (i=0; i<PCSCLITE_MAX_READERS_CONTEXTS; i++)
@@ -466,14 +464,18 @@ static void HPAddDevice(struct udev_device *dev)
 		sSerialNumber = udev_device_get_sysattr_value(parent, "serial");
 
 	/* name from the Info.plist file */
-	strlcpy(fullname, driver->readerName, sizeof(fullname));
+	fullname = strdup(driver->readerName);
 
 	/* interface name from the device (if any) */
 	if (sInterfaceName)
 	{
-		strlcat(fullname, " [", sizeof(fullname));
-		strlcat(fullname, sInterfaceName, sizeof(fullname));
-		strlcat(fullname, "]", sizeof(fullname));
+		char *result;
+
+		/* create a new name */
+		asprintf(&result, "%s [%s]", fullname, sInterfaceName);
+
+		free(fullname);
+		fullname = result;
 	}
 
 	/* serial number from the device (if any) */
@@ -483,9 +485,13 @@ static void HPAddDevice(struct udev_device *dev)
 		 * interface name */
 		if (!sInterfaceName || NULL == strstr(sInterfaceName, sSerialNumber))
 		{
-			strlcat(fullname, " (", sizeof(fullname));
-			strlcat(fullname, sSerialNumber, sizeof(fullname));
-			strlcat(fullname, ")", sizeof(fullname));
+			char *result;
+
+			/* create a new name */
+			asprintf(&result, "%s (%s)", fullname, sSerialNumber);
+
+			free(fullname);
+			fullname = result;
 		}
 	}
 
@@ -517,6 +523,9 @@ static void HPAddDevice(struct udev_device *dev)
 			(void)CheckForOpenCT();
 		}
 	}
+
+	free(fullname);
+	free(deviceName);
 } /* HPAddDevice */
 
 
