@@ -33,7 +33,7 @@ THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: readerfactory.c 7004 2014-10-02 09:26:36Z rousseau $
+ * $Id$
  */
 
 /**
@@ -61,7 +61,6 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "eventhandler.h"
 #include "ifdwrapper.h"
 #include "hotplug.h"
-#include "strlcpycat.h"
 #include "configfile.h"
 #include "utils.h"
 
@@ -145,6 +144,7 @@ LONG RFAllocateReaderSpace(unsigned int customMaxReaderHandles)
 		/* Zero out each value in the struct */
 		memset(readerStates[i].readerName, 0, MAX_READERNAME);
 		memset(readerStates[i].cardAtr, 0, MAX_ATR_SIZE);
+		readerStates[i].eventCounter = 0;
 		readerStates[i].readerState = 0;
 		readerStates[i].readerSharing = 0;
 		readerStates[i].cardAtrLength = READER_NOT_INITIALIZED;
@@ -409,7 +409,7 @@ LONG RFAddReader(const char *readerNameLong, int port, const char *library,
 
 		/* Copy the previous reader name and increment the slot number */
 		tmpReader = sReadersContexts[dwContextB]->readerState->readerName;
-		(void)strlcpy(tmpReader,
+		memcpy(tmpReader,
 			sReadersContexts[dwContext]->readerState->readerName,
 			sizeof(sReadersContexts[dwContextB]->readerState->readerName));
 		snprintf(tmpReader + strlen(tmpReader) - 2, 3, "%02X", j);
@@ -692,7 +692,7 @@ LONG RFSetReaderName(READER_CONTEXT * rContext, const char *readerName,
 
 						/*
 						 * tells the caller who the parent of this
-						 * clone is so it can use it's shared
+						 * clone is so it can use its shared
 						 * resources like mutex/etc.
 						 */
 						parent = i;
