@@ -31,7 +31,7 @@ THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: winscard_msg.c 7004 2014-10-02 09:26:36Z rousseau $
+ * $Id$
  */
 
 /**
@@ -68,7 +68,6 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "winscard_msg.h"
 #include "sys_generic.h"
 #include "utils.h"
-#include "strlcpycat.h"
 
 #ifdef PCSCD
 
@@ -93,9 +92,12 @@ char *getSocketName(void)
 
 		socketNameEnv = getenv("PCSCLITE_CSOCK_NAME");
 		if (socketNameEnv)
-			strlcpy(socketName, socketNameEnv, sizeof(socketName));
+			strncpy(socketName, socketNameEnv, sizeof(socketName));
 		else
-			strlcpy(socketName, PCSCLITE_CSOCK_NAME, sizeof(socketName));
+			strncpy(socketName, PCSCLITE_CSOCK_NAME, sizeof(socketName));
+
+		/* Ensure a NUL byte */
+		socketName[sizeof socketName -1] = '\0';
 	}
 
 	return socketName;
