@@ -33,7 +33,7 @@ THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: winscard_svc.c 7004 2014-10-02 09:26:36Z rousseau $
+ * $Id$
  */
 
 /**
@@ -638,12 +638,18 @@ static void ContextThread(LPVOID newContext)
 				ioSendPci.cbPciLength = trStr.ioSendPciLength;
 				ioRecvPci.dwProtocol = trStr.ioRecvPciProtocol;
 				ioRecvPci.cbPciLength = trStr.ioRecvPciLength;
-				cbRecvLength = trStr.pcbRecvLength;
+				cbRecvLength = sizeof pbRecvBuffer;
 
 				trStr.rv = SCardTransmit(trStr.hCard, &ioSendPci,
 					pbSendBuffer, trStr.cbSendLength, &ioRecvPci,
 					pbRecvBuffer, &cbRecvLength);
 
+				if (cbRecvLength > trStr.pcbRecvLength)
+					/* The client buffer is not large enough.
+					 * The pbRecvBuffer buffer will NOT be sent a few
+					 * lines bellow. So no buffer overflow is expected. */
+					trStr.rv = SCARD_E_INSUFFICIENT_BUFFER;
+
 				trStr.ioSendPciProtocol = ioSendPci.dwProtocol;
 				trStr.ioSendPciLength = ioSendPci.cbPciLength;
 				trStr.ioRecvPciProtocol = ioRecvPci.dwProtocol;
